diff Core/DicomFormat/DicomMap.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents c1097a676eca
children 293038baf8f1
line wrap: on
line diff
--- a/Core/DicomFormat/DicomMap.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/Core/DicomFormat/DicomMap.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -23,10 +23,10 @@
 #include <stdio.h>
 #include <memory>
 #include "DicomString.h"
-#include "../PalantirException.h"
+#include "../PalanthirException.h"
 
 
-namespace Palantir
+namespace Palanthir
 {
   static DicomTag patientTags[] =
   {
@@ -177,7 +177,7 @@
 
     if (it == map_.end())
     {
-      throw PalantirException("Inexistent tag");
+      throw PalanthirException("Inexistent tag");
     }
     else
     {
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium